@@ -5,7 +5,7 @@
 ;;   Copyright (C) 2002,2003,2004,2005 Kiyoka Nishyama
 ;;   This program was derived from yc.el-4.0.13(auther: knak)
 ;;
-;;     $Date: 2005/10/05 12:45:08 $
+;;     $Date: 2005/10/24 15:31:34 $
 ;;
 ;; This file is part of Sumibi
 ;;
@@ -312,19 +312,36 @@ W/POuZ6lcg5Ktz885hZo+L7tdEy8W9ViH0Pd
 	nil))))
 
 
+;; $B%]!<%?%V%kJ8;zNsCV49(B( Emacs$B$H(BXEmacs$B$NN>J}$GF0$/(B )
+(defun sumibi-replace-regexp-in-string (regexp replace str)
+  (cond ((featurep 'xemacs)
+	 (replace-in-string str regexp replace))
+	(t
+	 (replace-regexp-in-string regexp replace str))))
+	
+
 ;; $BCV49%-!<%o!<%I$r2r7h$9$k(B
 (defun sumibi-replace-keyword (str)
   (let (
-	(word-list (split-string str)))
-    (mapconcat
-     (lambda (x)
-       (let ((val (assoc x sumibi-replace-keyword-list)))
-	 (if val
-	     (cdr val)
-	   x)))
-     word-list
-     " ")))
+	;; $B2~9T$r0l$D$N%9%Z!<%9$KCV49$7$F!"(B
+	;; $B%-!<%o!<%ICV49=hM}$NA0=hM}$H$7$F9TF,$H9TKv$K%9%Z!<%9$rDI2C$9$k!#(B
+	(replaced 
+	 (concat " " 
+		 (sumibi-replace-regexp-in-string 
+		  "[\n]"
+		  " "
+		  str)
+		 " ")))
 
+    (mapcar
+     (lambda (x)
+       (setq replaced 
+	     (sumibi-replace-regexp-in-string 
+	      (concat " " (car x) " ")
+	      (concat " " (cdr x) " ")
+	      replaced)))
+     sumibi-replace-keyword-list)
+    replaced))
 
 ;; $B%j!<%8%g%s$r%m!<%^;z4A;zJQ49$9$k4X?t(B
 (defun sumibi-henkan-region (b e)
@@ -345,7 +362,7 @@ W/POuZ6lcg5Ktz885hZo+L7tdEy8W9ViH0Pd
 		  (setq henkan-list
 			(list
 			 (append
-			  `((j ,(cdr _) 0 0))
+			  `((j ,(cdr _) 0 0 0))
 			  (car henkan-list)))))))
 		
 	    (condition-case err
@@ -465,24 +482,30 @@ W/POuZ6lcg5Ktz885hZo+L7tdEy8W9ViH0Pd
 		(start       (point-marker))
 		(_n          (nth cnt sumibi-cand-n))
 		(_max        (nth cnt sumibi-cand-max))
+		(spaces      (nth 4 (nth _n x)))
 		(insert-word (cadr (nth _n x)))
+		(_insert-word
+		 ;; $B%9%Z!<%9$,(B2$B8D0J>eF~$l$i$l$?$i!"(B1$B8D$N%9%Z!<%9$rF~$l$k!#(B($BC"$7!"(Bauto-fill-mode$B$,L58z$N>l9g$N$_(B)
+		 (if (and (< 1 spaces) (not auto-fill-function))
+		     (concat " " insert-word)
+		   insert-word))
 		(ank-word    (cadr (assoc 'l x)))
 		(_     
 		 (if (eq cnt sumibi-cand)
 		     (progn
-		       (insert insert-word)
+		       (insert _insert-word)
 		       (message (format "[%s] candidate (%d/%d)" insert-word (+ _n 1) _max))
 		       ;; $B%f!<%6!<<-=q$KEPO?$9$k(B
 		       (setq sumibi-kakutei-history 
 			     (append
 			      `((,ank-word . ,insert-word))
 			      sumibi-kakutei-history)))
-		   (insert insert-word)))
+		   (insert _insert-word)))
 		(end         (point-marker))
 		(ov          (make-overlay start end)))
 
 	   ;; $B3NDjJ8;zNs$N:n@.(B
-	   (setq sumibi-last-fix (concat sumibi-last-fix insert-word))
+	   (setq sumibi-last-fix (concat sumibi-last-fix _insert-word))
 	   
 	   ;; $BA*BrCf$N>l=j$rAu>~$9$k!#(B
 	   (overlay-put ov 'face 'default)
@@ -933,7 +956,10 @@ point $B$+$i9TF,J}8~$KF1<o$NJ8;zNs$,B3$/4V$r4A;zJQ49$7$^$9!#(B
   "$BF~NO%b!<%IJQ99(B"
   (interactive "P")
   (if (< 0 arg)
-      (setq sumibi-mode t)
+      (progn
+	(setq inactivate-current-input-method-function 'sumibi-inactivate)
+	(setq sumibi-mode t))
+    (setq inactivate-current-input-method-function nil)
     (setq sumibi-mode nil)))
 
 
@@ -952,7 +978,7 @@ point $B$+$i9TF,J}8~$KF1<o$NJ8;zNs$,B3$/4V$r4A;zJQ49$7$^$9!#(B
 (setq default-input-method "japanese-sumibi")
 
 (defconst sumibi-version
-"0.5.1"
+"0.5.2"
   )
 (defun sumibi-version (&optional arg)
   "$BF~NO%b!<%IJQ99(B"
